==> thx-cron-0.1.1.tar.gz: thx-cron-0.1.1/thx/cron/api/version1/serializers.py <==
# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models


# JOB
class JobSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        fields = '__all__'


class JobListSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobRetrieveSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobCreateSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobListSerializer(instance, context=self.context).data


class JobUpdateSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobPartialUpdateSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobUpdateMessageSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobEnableSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobDisableSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Job
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


# JOB LOG
class JobLogSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.JobLog
        fields = '__all__'


class JobLogListSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.JobLog
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobLogRetrieveSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.JobLog
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobLogEnableSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.JobLog
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobLogRetrieveSerializer(instance, context=self.context).data


class JobLogDisableSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.JobLog
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobLogRetrieveSerializer(instance, context=self.context).data

==> thx-cron-0.2.6.tar.gz: thx-cron-0.2.6/thx/cron/api/version1/serializers.py <==
# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)


# JOB
class JobSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job'
        model = models.Job
        fields = '__all__'


class JobListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_list'
        model = models.Job
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_retrieve'
        model = models.Job
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_create'
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobListSerializer(instance, context=self.context).data


class JobUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_update'
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_partial_update'
        model = models.Job
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_enable'
        model = models.Job
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


class JobDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_disable'
        model = models.Job
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobRetrieveSerializer(instance, context=self.context).data


# JOB LOG
class JobLogSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log'
        model = models.JobLog
        fields = '__all__'


class JobLogListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_list'
        model = models.JobLog
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobLogRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_retrieve'
        model = models.JobLog
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        return []


class JobLogEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_enable'
        model = models.JobLog
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobLogRetrieveSerializer(instance, context=self.context).data


class JobLogDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_cron_job_log_disable'
        model = models.JobLog
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return JobLogRetrieveSerializer(instance, context=self.context).data
